window.Gleam.initSearch([{"doc":"glex","title":"glex","content":"# glex\n\n[![Package Version](https://img.shields.io/hexpm/v/glex)](https://hex.pm/packages/glex)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glex/)\n\n## A simple lexer generator for Gleam\n\n`glex` is a simple lexer generator for Gleam. It is inspired by the [`rply`](https://github.com/alex/rply) lexer generator and [`glexer`](https://github.com/DanielleMaywood/glexer).\n\n```sh\ngleam add glex\n```\n\n```gleam\nimport gleam/io\nimport gleam/list\nimport gleam/string\nimport glex\n\npub fn main() {\n  // Making a lexer for a simple rung of ladder logic\n\n  let file_type = &quot;([A-Za-z]){1,2}&quot;\n  let file_number = &quot;([2-9]?[0-5]?[0-5]?)?&quot;\n  let element_delimiter = &quot;(:|/)&quot;\n  let element_number = &quot;(\\\\d{1,4}|[A-Za-z]{1,4})&quot;\n  let word_delimiter = &quot;([.|/])?&quot;\n  let word_number = &quot;(\\\\d{1,4}|[A-Za-z]{1,4})?&quot;\n  let bit_delimiter = &quot;(/)?&quot;\n  let bit_number = &quot;(\\\\d{1,4}|[A-Za-z]{1,4})?&quot;\n\n  let address =\n    string.concat([\n      file_type,\n      file_number,\n      element_delimiter,\n      element_number,\n      word_delimiter,\n      word_number,\n      bit_delimiter,\n      bit_number,\n    ])\n\n  let rung = &quot;SOR XIC T4:0.1/DN OTE B3/0 EOR&quot;\n\n  let tokens =\n    glex.new()\n    |&gt; glex.add_rule(&quot;SOR&quot;, &quot;SOR&quot;)\n    |&gt; glex.add_rule(&quot;EOR&quot;, &quot;EOR&quot;)\n    |&gt; glex.add_rule(&quot;XIC&quot;, &quot;XIC&quot;)\n    |&gt; glex.add_rule(&quot;OTE&quot;, &quot;OTE&quot;)\n    |&gt; glex.add_rule(&quot;ADDRESS&quot;, address)\n    |&gt; glex.add_ignore(&quot;whitespace&quot;, &quot;\\\\s+&quot;)\n    |&gt; glex.build(rung)\n    |&gt; glex.lex()\n\n  tokens\n  |&gt; list.each(io.debug)\n  // #(Valid(&quot;SOR&quot;, &quot;SOR&quot;), Position(0))\n  // #(Ignored(&quot;whitespace&quot;, &quot; &quot;), Position(3))\n  // #(Valid(&quot;XIC&quot;, &quot;XIC&quot;), Position(4))\n  // #(Ignored(&quot;whitespace&quot;, &quot; &quot;), Position(7))\n  // #(Valid(&quot;ADDRESS&quot;, &quot;T4:0.1/DN&quot;), Position(8))\n  // #(Ignored(&quot;whitespace&quot;, &quot; &quot;), Position(17))\n  // #(Valid(&quot;OTE&quot;, &quot;OTE&quot;), Position(18))\n  // #(Ignored(&quot;whitespace&quot;, &quot; &quot;), Position(21))\n  // #(Valid(&quot;ADDRESS&quot;, &quot;B3/0&quot;), Position(22))\n  // #(Ignored(&quot;whitespace&quot;, &quot; &quot;), Position(26))\n  // #(Valid(&quot;EOR&quot;, &quot;EOR&quot;), Position(27))\n\n  tokens\n  |&gt; glex.ok()\n  |&gt; io.debug\n  // True\n\n  tokens\n  |&gt; glex.valid_only()\n  |&gt; list.each(io.debug)\n  // #(Valid(&quot;SOR&quot;, &quot;SOR&quot;), Position(0))\n  // #(Valid(&quot;XIC&quot;, &quot;XIC&quot;), Position(4))\n  // #(Valid(&quot;ADDRESS&quot;, &quot;T4:0.1/DN&quot;), Position(8))\n  // #(Valid(&quot;OTE&quot;, &quot;OTE&quot;), Position(18))\n  // #(Valid(&quot;ADDRESS&quot;, &quot;B3/0&quot;), Position(22))\n  // #(Valid(&quot;EOR&quot;, &quot;EOR&quot;), Position(27))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glex&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glex","title":"Lexer","content":"pub opaque type Lexer\n\n\nSynonyms:\nglex.Lexer\nglex Lexer","url":"glex.html#Lexer"},{"doc":"glex","title":"Position","content":"pub type Position {\n  Position(Int)\n}\n\nPosition(Int)\n\n\nSynonyms:\nglex.Position\nglex Position","url":"glex.html#Position"},{"doc":"glex","title":"Rule","content":"pub opaque type Rule\n\n\nSynonyms:\nglex.Rule\nglex Rule","url":"glex.html#Rule"},{"doc":"glex","title":"Token","content":"pub type Token {\n  Valid(name: String, value: String)\n  Ignored(name: String, value: String)\n  Invalid(value: String)\n  EndOfFile\n}\n\nValid(name: String, value: String)\n\n\nIgnored(name: String, value: String)\n\n\nInvalid(value: String)\n\n\nEndOfFile\n\n\nSynonyms:\nglex.Token\nglex Token","url":"glex.html#Token"},{"doc":"glex","title":"add_ignore","content":"pub fn add_ignore(\n  lexer: Lexer,\n  name: String,\n  pattern: String,\n) -&gt; Lexer\n\nSynonyms:\nglex.add_ignore\nglex add_ignore","url":"glex.html#add_ignore"},{"doc":"glex","title":"add_rule","content":"pub fn add_rule(\n  lexer: Lexer,\n  name: String,\n  pattern: String,\n) -&gt; Lexer\n\nSynonyms:\nglex.add_rule\nglex add_rule","url":"glex.html#add_rule"},{"doc":"glex","title":"build","content":"pub fn build(lexer: Lexer, source: String) -&gt; Lexer\n\nSynonyms:\nglex.build\nglex build","url":"glex.html#build"},{"doc":"glex","title":"ignored_only","content":"pub fn ignored_only(\n  tokens: List(#(Token, Position)),\n) -&gt; List(#(Token, Position))\n\nSynonyms:\nglex.ignored_only\nglex ignored_only","url":"glex.html#ignored_only"},{"doc":"glex","title":"invalid_only","content":"pub fn invalid_only(\n  tokens: List(#(Token, Position)),\n) -&gt; List(#(Token, Position))\n\nSynonyms:\nglex.invalid_only\nglex invalid_only","url":"glex.html#invalid_only"},{"doc":"glex","title":"iterator","content":"pub fn iterator(lexer: Lexer) -&gt; Iterator(#(Token, Position))\n\nSynonyms:\nglex.iterator\nglex iterator","url":"glex.html#iterator"},{"doc":"glex","title":"lex","content":"pub fn lex(lexer: Lexer) -&gt; List(#(Token, Position))\n\nSynonyms:\nglex.lex\nglex lex","url":"glex.html#lex"},{"doc":"glex","title":"new","content":"pub fn new() -&gt; Lexer\n\nSynonyms:\nglex.new\nglex new","url":"glex.html#new"},{"doc":"glex","title":"new_rule","content":"pub fn new_rule(name: String, pattern: String) -&gt; Rule\n\nSynonyms:\nglex.new_rule\nglex new_rule","url":"glex.html#new_rule"},{"doc":"glex","title":"next","content":"pub fn next(lexer: Lexer) -&gt; #(Lexer, #(Token, Position))\n\nSynonyms:\nglex.next\nglex next","url":"glex.html#next"},{"doc":"glex","title":"ok","content":"pub fn ok(tokens: List(#(Token, Position))) -&gt; Bool\n\nSynonyms:\nglex.ok\nglex ok","url":"glex.html#ok"},{"doc":"glex","title":"valid_only","content":"pub fn valid_only(\n  tokens: List(#(Token, Position)),\n) -&gt; List(#(Token, Position))\n\nSynonyms:\nglex.valid_only\nglex valid_only","url":"glex.html#valid_only"},{"doc":"glex","title":"glex","content":"","url":"glex.html"}]);